# Dangr run time

**dangr_rt** is the runtime library for **dangr**, a declarative language tailored for semantic pattern detection in binary analysis. The dangr run time uses the **angr** framework to facilitate powerful symbolic execution and analysis. **dangr_rt** provides core functionalities and utilities needed to execute and analyze compiled dangr code at runtime.

## Getting Started

```bash
# Install
poetry shell
poetry install

# Test
pytest
```
